==========
argskwargs
==========

.. image:: https://travis-ci.org/wbolster/argskwargs.svg?branch=master
    :target: https://travis-ci.org/wbolster/argskwargs

``argskwargs`` is a small Python library that provides a flexible container for
positional and keyword arguments.

* Documentation: https://argskwargs.readthedocs.io/

* Python Package Index (PyPI): https://pypi.python.org/pypi/argskwargs/

* Source code and issue tracker: https://github.com/wbolster/argskwargs
